#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// Balanced System
    /// </summary>
    [Description("Balanced System")]
    public class ZsForexBalancedSystem : Strategy
    {
        #region Variables
        // Wizard generated variables
        private int perioD = 3; // Default setting for PerioD
        private int perioK = 14; // Default setting for PerioK
        private int perioRSI = 14; // Default setting for PerioRSI
        private int perioSmooth = 3; // Default setting for PerioSmooth
        private int perioEMA1 = 5; // Default setting for PerioEMA1
        private int perioEMA2 = 10; // Default setting for PerioEMA2
        // User defined variables (add any user defined variables below)
		private DataSeries dsK, dsD, dsRSI, dsEMA1, dsEMA2;
		private double maxPerio = 0.0;
		private bool _buy1 = false, _sell1 = false, _buy2 = false, _sell2 = false, _buy3 = false, _sell3 = false, _buy4 = false, _sell4 = false;
		private int _pos1 = 0, _pos2 = 0;
		private bool firstTime = true;
        #endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose = true;
			
			dsK 	= new DataSeries(this);
			dsD		= new DataSeries(this);
			dsRSI 	= new DataSeries(this);
			dsEMA1 	= new DataSeries(this);
			dsEMA2	= new DataSeries(this);
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if ( firstTime )
			{
				maxPerio = Math.Max( perioK, Math.Max( perioD, Math.Max( perioRSI, Math.Max( perioSmooth, Math.Max(perioEMA1, perioEMA2) ) ) ) );
				firstTime = false;
			}
			
			if ( CurrentBar < maxPerio )
				return;
			
			dsK.Set( 0, Stochastics( perioD, perioK, perioSmooth).K[0]);
			dsD.Set( 0, Stochastics( perioD, perioK, perioSmooth).D[0]);
			dsRSI.Set(0, RSI(perioRSI,1)[0]);
			dsEMA1.Set(0, EMA( perioEMA1)[0]);
			dsEMA2.Set(0, EMA( perioEMA2)[0]);
			
			#region Condiciones
			// Cruces de EMAs
			if ( dsEMA1[1] <= dsEMA2[1] && dsEMA1[0] > dsEMA2[0])
			{
				_buy1 	= true;
				_sell1	= false;
				_pos1	= CurrentBar;
			}
			if ( dsEMA1[1] >= dsEMA2[1] && dsEMA1[0] < dsEMA2[0])
			{
				_sell1	= true;
				_buy1 	= false;
				_pos1	= CurrentBar;
			}
			
			// Cruces del stochastic
			if ( dsK[1] <= dsD[1] && dsK[0] > dsD[0] )
			{
				_buy2 	= true;
				_sell2	= false;
				_pos2	= CurrentBar;
			}
			if ( dsK[1] >= dsD[1] && dsK[0] < dsD[0] )
			{
				_sell2	= true;
				_buy2 	= false;
				_pos2	= CurrentBar;
			}
			
			// RSI50
			if ( dsRSI[0] > 50 )
			{
				_buy3	= true;
				_sell3	= false;
			}
			if ( dsRSI[0] < 50 )
			{
				_sell3	= true;
				_buy3	= false;
			}
			
			// Overbought, oversold
			if ( Math.Min( dsD[0], dsK[0] ) < 20 )
				_sell4	= false;
			else if ( Math.Max( dsD[0], dsK[0] ) > 80 )
				_buy4	= false;
			else
			{
				_buy4	= true;
				_sell4 	= true;
			}
			#endregion
			
			if ( _buy1 && _buy2 && _buy3 && _buy4 )
				EnterLong( 1, "EntrarLargo");
			if ( _sell1 && _sell2 && _sell3 && _sell4 )
				EnterShort(1, "EntrarCorto");
        }

        #region Properties
        [Description("Período %D Stochastic")]
        [Category("Parameters")]
        public int PerioD
        {
            get { return perioD; }
            set { perioD = Math.Max(1, value); }
        }

        [Description("Período %K Stochastic")]
        [Category("Parameters")]
        public int PerioK
        {
            get { return perioK; }
            set { perioK = Math.Max(1, value); }
        }

        [Description("Período RSI")]
        [Category("Parameters")]
        public int PerioRSI
        {
            get { return perioRSI; }
            set { perioRSI = Math.Max(1, value); }
        }

        [Description("Período Smooth Stochastic")]
        [Category("Parameters")]
        public int PerioSmooth
        {
            get { return perioSmooth; }
            set { perioSmooth = Math.Max(1, value); }
        }

        [Description("Período EMA Fast")]
        [Category("Parameters")]
        public int PerioEMA1
        {
            get { return perioEMA1; }
            set { perioEMA1 = Math.Max(1, value); }
        }

        [Description("Período EMA Slow")]
        [Category("Parameters")]
        public int PerioEMA2
        {
            get { return perioEMA2; }
            set { perioEMA2 = Math.Max(1, value); }
        }
        #endregion
    }
}
